@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -368,8 +368,11 @@ import_show (SeahorseToolMode *mode)
     if (mode->imports <= 0)
         return;
     
-    t = g_strdup_printf (mode->imports == 1 ? _("Imported key") : 
-                                              _("Imported %d keys"), mode->imports);
+    if (mode->imports == 1)
+	t = g_strdup_printf (_("Imported key"));
+    else
+	t = g_strdup_printf (ngettext ("Imported %d key", "Imported %d keys", mode->imports), mode->imports);
+        
     dlg = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                   GTK_MESSAGE_INFO, GTK_BUTTONS_OK, t);
     g_free (t);
@@ -550,22 +553,8 @@ main (int argc, char **argv)
     gchar **uris = NULL;
     int ret = 0;
 
-    seahorse_secure_memory_init (65536);
-    
-    /* We need to drop privileges completely for security */
-#if defined(HAVE_SETRESUID) && defined(HAVE_SETRESGID)
-
-    /* Not in header files for all OSs, even where present */
-    int setresuid(uid_t ruid, uid_t euid, uid_t suid);
-    int setresgid(gid_t rgid, gid_t egid, gid_t sgid);
-  
-    if (setresuid (getuid (), getuid (), getuid ()) == -1 ||
-        setresgid (getgid (), getgid (), getgid ()) == -1)
-#else
-    if (setuid (getuid ()) == -1 || setgid (getgid ()) == -1)
-#endif
-        g_error (_("couldn't drop privileges properly"));
-    
+    seahorse_secure_memory_init ();
+        
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
