@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,7 @@
 #include "seahorse-gpgmex.h"
 #include "seahorse-passphrase.h"
 
-#ifdef WITH_GNOME_KEYRING
 #include <gnome-keyring.h>
-#endif
 
 #ifndef DEBUG_OPERATION_ENABLE
 #if _DEBUG
@@ -203,19 +201,19 @@ seahorse_gkeyring_operation_parse_error (GnomeKeyringResult result, GError **err
     /* An error mark it as such */
     switch (result) {
     case GNOME_KEYRING_RESULT_DENIED:
-        message = _("Access to the keyring was denied");
+        message = _("Access to the key ring was denied");
         break;
     case GNOME_KEYRING_RESULT_NO_KEYRING_DAEMON:
-        message = _("The GNOME keyring daemon is not running");
+        message = _("The gnome-keyring daemon is not running");
         break;
     case GNOME_KEYRING_RESULT_ALREADY_UNLOCKED:
-        message = _("The keyring has already been unlocked");
+        message = _("The key ring has already been unlocked");
         break;
     case GNOME_KEYRING_RESULT_NO_SUCH_KEYRING:
-        message = _("No such keyring exists");
+        message = _("No such key ring exists");
         break;
     case GNOME_KEYRING_RESULT_IO_ERROR:
-        message = _("Couldn't communicate with keyring daemon");
+        message = _("Couldn't communicate with key ring daemon");
         break;
     case GNOME_KEYRING_RESULT_ALREADY_EXISTS:
         message = _("The item already exists");
@@ -224,7 +222,7 @@ seahorse_gkeyring_operation_parse_error (GnomeKeyringResult result, GError **err
         g_warning ("bad arguments passed to gnome-keyring API");
         /* Fall through */
     default:
-        message = _("Internal error accessing GNOME keyring");
+        message = _("Internal error accessing gnome-keyring");
         break;
     }
     
@@ -272,6 +270,8 @@ seahorse_gkeyring_operation_update_info (SeahorseGKeyringItem *git, GnomeKeyring
     pv = SEAHORSE_GKEYRING_OPERATION_GET_PRIVATE (gop);
     
     keyring_name = seahorse_gkeyring_source_get_keyring_name (SEAHORSE_GKEYRING_SOURCE (sksrc));
+    g_return_val_if_fail (keyring_name != NULL, NULL);
+
     pv->keyid = seahorse_key_get_keyid (SEAHORSE_KEY (git));
     
     /* Start actual save request */
